move_node

Function move_node 

pub fn move_node(
    source: &str,
    file: &RelativePath,
    node: &NodeRef,
    target: &NodeRef,
    position: InsertPosition,
) -> Result<MutationResult, String>
Move a node to a new position relative to a target. Both nodes must be in the same file (same source text).